@@ -15,6 +15,7 @@
 
 import contextlib
 import json
+import os
 import telnetlib
 import time
 
@@ -116,6 +117,12 @@ class ITestCase(unittest2.TestCase):
         data = json.loads(post.content)
         return data
 
+    def put_object(self, url, object_id, body, code):
+        data = self._put(url + object_id, json.dumps(body))
+        self.assertEquals(data.status_code, code)
+        data = json.loads(data.content)
+        return data
+
     def get_object(self, url, obj_id, code, printing=False):
         rv = self._get(url + obj_id, printing)
         self.assertEquals(rv.status_code, code)
@@ -149,7 +156,7 @@ class ITestCase(unittest2.TestCase):
             data = data[crud_object]
             object_id = data.get('id')
             if crud_object == 'cluster':
-                self.await_cluster_active(get_url, object_id)
+                self.await_cluster_active(object_id)
         except Exception as e:
             self.fail('failure: ' + str(e))
         finally:
@@ -353,8 +360,8 @@ class ITestCase(unittest2.TestCase):
 
 #------------------------------helper_methods----------------------------------
 
-    def await_cluster_active(self, get_url, object_id):
-        get_data = self.get_object(get_url, object_id, 200)
+    def await_cluster_active(self, object_id):
+        get_data = self.get_object(self.url_cluster_with_slash, object_id, 200)
         get_data = get_data['cluster']
         i = 1
         while get_data['status'] != 'Active':
@@ -364,7 +371,8 @@ class ITestCase(unittest2.TestCase):
                 self.fail(
                     'cluster is not getting status \'Active\', '
                     'passed %d minutes' % param.TIMEOUT)
-            get_data = self.get_object(get_url, object_id, 200)
+            get_data = self.get_object(
+                self.url_cluster_with_slash, object_id, 200)
             get_data = get_data['cluster']
             time.sleep(10)
             i += 1
@@ -389,10 +397,12 @@ class ITestCase(unittest2.TestCase):
         with contextlib.closing(self.ssh_connection(host)) as ssh:
             return remote.read_file_from(ssh.open_sftp(), remote_file)
 
-    def transfer_script_to_node(self, host, directory, folder, script):
-        self.write_file_to(
-            str(host), 'script.sh',
-            open('%s/integration/%s/%s' % (directory, folder, script)).read())
+    def transfer_script_to_node(self, host,
+                                script='hadoop_test/hadoop_test_script.sh'):
+        self.write_file_to(str(host),
+                           'script.sh',
+                           open('%s/integration/%s' % (os.getcwd(),
+                                                       script)).read())
         self.execute_command(str(host), 'chmod 777 script.sh')
 
     def try_telnet(self, host, port):
@@ -407,10 +417,20 @@ class ITestCase(unittest2.TestCase):
         data = self.post_object(self.url_cluster, cluster_body, 202)
         cluster_id = data['cluster']['id']
 
-        self.await_cluster_active(self.url_cluster_with_slash, cluster_id)
+        self.await_cluster_active(cluster_id)
 
         return cluster_id
 
+    def create_cluster_using_ngt_and_get_id(self, cl_tmpl_id, name):
+        try:
+            clstr_body = self.make_cl_body_cluster_template(cl_tmpl_id)
+            clstr_body['name'] = name
+            return self.create_cluster_and_get_id(clstr_body)
+
+        except Exception as e:
+            self.del_object(self.url_cl_tmpl_with_slash, cl_tmpl_id, 204)
+            self.fail('failure: ' + str(e))
+
     def get_instances_ip_and_node_processes_list(self, cluster_id):
         get_data = self.get_object(
             self.url_cluster_with_slash, cluster_id, 200, True)
@@ -465,7 +485,7 @@ class ITestCase(unittest2.TestCase):
         }
 
     def await_active_workers_for_namenode(self, data):
-        attempts_count = 10
+        attempts_count = 20
 
         while True:
             active_tasktrackers_count = int(
@@ -487,7 +507,7 @@ class ITestCase(unittest2.TestCase):
 
             if attempts_count == 0:
                 self.fail('tasktracker or datanode cannot be started '
-                          'within 30 sec.')
+                          'within 1 minute.')
 
             time.sleep(3)
 
